# Create Components

Panel components are the building blocks and visual layouts of your app or dashboard. These How-to pages provide solutions for common tasks related to creating, using and updating components.

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`rocket;2.5em;sd-mr-1 sd-animate-grow50` Construct Panes
:link: construct_panes
:link-type: doc

How to construct Pane objects for displaying visible components.
:::

:::{grid-item-card} {octicon}`unverified;2.5em;sd-mr-1 sd-animate-grow50` Access Pane Type
:link: pane_type
:link-type: doc

How to access Pane Type.
:::

:::{grid-item-card} {octicon}`telescope;2.5em;sd-mr-1 sd-animate-grow50` Access Widget Values
:link: widget_values
:link-type: doc

How to access and set widget values.
:::

:::{grid-item-card} {octicon}`file-diff;2.5em;sd-mr-1 sd-animate-grow50` Add or Remove Components
:link: add_remove
:link-type: doc

How to add or remove components from a panel.
:::
::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

construct_panes
pane_type
widget_values
add_remove
```
